==> tuia-advert-center-api-1.5.9-20180715.104744-16-sources.jar: cn/com/duiba/tuia/core/api/dto/homepage/HomePageTabDataDto.java <==
package cn.com.duiba.tuia.core.api.dto.homepage;

import java.math.BigDecimal;

/**
 * Created by huangch on 2018/6/22 15:17
 * description:
 *
 * @since JDK 1.6
 */
public class HomePageTabDataDto {

    //账号id，用于免登陆
    private Long accountId;

    //公司名称(广告主名称)
    private String companyName;

    //客户类型,1-一般客户，2-KA客户，3-准KA客户
    private Integer advertiserType;

    //消耗
    private Long consume;

    //消耗环比,今日tab数据为消耗/预算
    private BigDecimal consumeHb;

    //消耗环比状态，0-降，1-升
    private Integer consumeHbStatus;

    //CTR
    private Float ctr;

    //CTR环比
    private BigDecimal ctrHb;

    //CTR环比状态，0-降，1-升
    private Integer ctrHbStatus;

    //CVR
    private Float cvr;

    //CVR环比
    private BigDecimal cvrHb;

    //CVR环比状态，0-降，1-升
    private Integer cvrHbStatus;

    //ARPU
    private BigDecimal arpu;

    //arpu环比
    private BigDecimal arpuHb;

    //arpu环比状态，0-降，1-升
    private Integer arpuHbStatus;

    //点击成本
    private Long clickPrice;

    //点击成本环比
    private BigDecimal clickPriceHb;

    //点击成本环比状态，0-降，1-升
    private Integer clickPriceHbStatus;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getClickPrice() {
        return clickPrice;
    }

    public void setClickPrice(Long clickPrice) {
        this.clickPrice = clickPrice;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Integer getAdvertiserType() {
        return advertiserType;
    }

    public void setAdvertiserType(Integer advertiserType) {
        this.advertiserType = advertiserType;
    }

    public Long getConsume() {
        return consume;
    }

    public void setConsume(Long consume) {
        this.consume = consume;
    }

    public BigDecimal getConsumeHb() {
        return consumeHb;
    }

    public void setConsumeHb(BigDecimal consumeHb) {
        this.consumeHb = consumeHb;
    }

    public Integer getConsumeHbStatus() {
        return consumeHbStatus;
    }

    public void setConsumeHbStatus(Integer consumeHbStatus) {
        this.consumeHbStatus = consumeHbStatus;
    }

    public Float getCtr() {
        return ctr;
    }

    public void setCtr(Float ctr) {
        this.ctr = ctr;
    }

    public BigDecimal getCtrHb() {
        return ctrHb;
    }

    public void setCtrHb(BigDecimal ctrHb) {
        this.ctrHb = ctrHb;
    }

    public Integer getCtrHbStatus() {
        return ctrHbStatus;
    }

    public void setCtrHbStatus(Integer ctrHbStatus) {
        this.ctrHbStatus = ctrHbStatus;
    }

    public Float getCvr() {
        return cvr;
    }

    public void setCvr(Float cvr) {
        this.cvr = cvr;
    }

    public BigDecimal getCvrHb() {
        return cvrHb;
    }

    public void setCvrHb(BigDecimal cvrHb) {
        this.cvrHb = cvrHb;
    }

    public Integer getCvrHbStatus() {
        return cvrHbStatus;
    }

    public void setCvrHbStatus(Integer cvrHbStatus) {
        this.cvrHbStatus = cvrHbStatus;
    }

    public BigDecimal getArpu() {
        return arpu;
    }

    public void setArpu(BigDecimal arpu) {
        this.arpu = arpu;
    }

    public BigDecimal getArpuHb() {
        return arpuHb;
    }

    public void setArpuHb(BigDecimal arpuHb) {
        this.arpuHb = arpuHb;
    }

    public Integer getArpuHbStatus() {
        return arpuHbStatus;
    }

    public void setArpuHbStatus(Integer arpuHbStatus) {
        this.arpuHbStatus = arpuHbStatus;
    }

    public BigDecimal getClickPriceHb() {
        return clickPriceHb;
    }

    public void setClickPriceHb(BigDecimal clickPriceHb) {
        this.clickPriceHb = clickPriceHb;
    }

    public Integer getClickPriceHbStatus() {
        return clickPriceHbStatus;
    }

    public void setClickPriceHbStatus(Integer clickPriceHbStatus) {
        this.clickPriceHbStatus = clickPriceHbStatus;
    }
}

==> tuia-advert-center-api-1.7.4-r-20181016.122044-2-sources.jar: cn/com/duiba/tuia/core/api/dto/homepage/HomePageTabDataDto.java <==
package cn.com.duiba.tuia.core.api.dto.homepage;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * Created by huangch on 2018/6/22 15:17
 * description:
 *
 * @since JDK 1.6
 */
public class HomePageTabDataDto  implements Serializable {

    private static final long serialVersionUID = -3645976068479137129L;
    //账号id，用于免登陆
    private Long accountId;

    //公司名称(广告主名称)
    private String companyName;

    //客户类型,1-一般客户，2-KA客户，3-准KA客户
    private Integer advertiserType;

    //消耗
    private Long consume;

    //消耗环比,今日tab数据为消耗/预算
    private BigDecimal consumeHb;

    //消耗环比状态，0-降，1-升
    private Integer consumeHbStatus;

    //CTR
    private Float ctr;

    //CTR环比
    private BigDecimal ctrHb;

    //CTR环比状态，0-降，1-升
    private Integer ctrHbStatus;

    //CVR
    private Float cvr;

    //CVR环比
    private BigDecimal cvrHb;

    //CVR环比状态，0-降，1-升
    private Integer cvrHbStatus;

    //ARPU
    private BigDecimal arpu;

    //arpu环比
    private BigDecimal arpuHb;

    //arpu环比状态，0-降，1-升
    private Integer arpuHbStatus;

    //点击成本
    private Long clickPrice;

    //点击成本环比
    private BigDecimal clickPriceHb;

    //点击成本环比状态，0-降，1-升
    private Integer clickPriceHbStatus;

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Long getClickPrice() {
        return clickPrice;
    }

    public void setClickPrice(Long clickPrice) {
        this.clickPrice = clickPrice;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Integer getAdvertiserType() {
        return advertiserType;
    }

    public void setAdvertiserType(Integer advertiserType) {
        this.advertiserType = advertiserType;
    }

    public Long getConsume() {
        return consume;
    }

    public void setConsume(Long consume) {
        this.consume = consume;
    }

    public BigDecimal getConsumeHb() {
        return consumeHb;
    }

    public void setConsumeHb(BigDecimal consumeHb) {
        this.consumeHb = consumeHb;
    }

    public Integer getConsumeHbStatus() {
        return consumeHbStatus;
    }

    public void setConsumeHbStatus(Integer consumeHbStatus) {
        this.consumeHbStatus = consumeHbStatus;
    }

    public Float getCtr() {
        return ctr;
    }

    public void setCtr(Float ctr) {
        this.ctr = ctr;
    }

    public BigDecimal getCtrHb() {
        return ctrHb;
    }

    public void setCtrHb(BigDecimal ctrHb) {
        this.ctrHb = ctrHb;
    }

    public Integer getCtrHbStatus() {
        return ctrHbStatus;
    }

    public void setCtrHbStatus(Integer ctrHbStatus) {
        this.ctrHbStatus = ctrHbStatus;
    }

    public Float getCvr() {
        return cvr;
    }

    public void setCvr(Float cvr) {
        this.cvr = cvr;
    }

    public BigDecimal getCvrHb() {
        return cvrHb;
    }

    public void setCvrHb(BigDecimal cvrHb) {
        this.cvrHb = cvrHb;
    }

    public Integer getCvrHbStatus() {
        return cvrHbStatus;
    }

    public void setCvrHbStatus(Integer cvrHbStatus) {
        this.cvrHbStatus = cvrHbStatus;
    }

    public BigDecimal getArpu() {
        return arpu;
    }

    public void setArpu(BigDecimal arpu) {
        this.arpu = arpu;
    }

    public BigDecimal getArpuHb() {
        return arpuHb;
    }

    public void setArpuHb(BigDecimal arpuHb) {
        this.arpuHb = arpuHb;
    }

    public Integer getArpuHbStatus() {
        return arpuHbStatus;
    }

    public void setArpuHbStatus(Integer arpuHbStatus) {
        this.arpuHbStatus = arpuHbStatus;
    }

    public BigDecimal getClickPriceHb() {
        return clickPriceHb;
    }

    public void setClickPriceHb(BigDecimal clickPriceHb) {
        this.clickPriceHb = clickPriceHb;
    }

    public Integer getClickPriceHbStatus() {
        return clickPriceHbStatus;
    }

    public void setClickPriceHbStatus(Integer clickPriceHbStatus) {
        this.clickPriceHbStatus = clickPriceHbStatus;
    }
}
